pro library

Functions

cancelOrder({required String orderId, String? profileId, String? productId, required Credential credential, bool isSandbox = false}) Future<bool>
Cancels a single order.
createOrder({required String side, required String productId, String? profileId, String? type, num? size, num? price, num? funds, String? timeInForce, String? stp, String? stop, num? stopPrice, String? cancelAfter, bool? postOnly, String? clientOid, required Credential credential, bool isSandbox = false}) Future<Order?>
Creates a new order.
getAccount(String accountId, {required Credential credential, bool isSandbox = false}) Future<Account?>
Gets a single account for the current user by account ID.
getAccountByCurrency(String currency, {required Credential credential, bool isSandbox = false}) Future<Account?>
Gets a single account for the current user by currency.
getAccounts({required Credential credential, bool isSandbox = false}) Future<List<Account>>
Gets a list of accounts for the current user.
getFees({required Credential credential, bool isSandbox = false}) Future<Fee?>
Gets the current fee rates for the user.
getFills({required String productId, int limit = 100, String profileId = 'default', required Credential credential, bool isSandbox = false}) Future<List<Fill>>
Gets a list of recent fills for a given product.
getFillsByOrderId(String orderID, {String profileId = 'default', required Credential credential, bool isSandbox = false}) Future<List<Fill>>
Gets a list of recent fills for a given order.
getOrder({required String orderId, required Credential credential, bool isSandbox = false}) Future<Order?>
Gets a single order for the current user by order ID.
getOrderByClientOid({required String clientOid, required Credential credential, bool isSandbox = false}) Future<Order?>
Gets a single order for the current user by client OID.
getOrders({int limit = 1000, String status = 'all', required Credential credential, bool isSandbox = false}) Future<List<Order>>
Gets a list of orders for the current user.
getProduct(String tickerId, {bool isSandbox = false}) Future<Product?>
Gets a single product by product ID.
getProducts({bool isSandbox = false}) Future<List<Product>>
Gets a list of available products.
getTicker(String tickerId, {bool isSandbox = false}) Future<Ticker?>
Gets snapshot information about the last trade (tick), best bid/ask and 24h volume.