Fee class

Constructors

Fee(double? makerFeeRate, double? takerFeeRate, double? usdVolume)

Properties

hashCode int
The hash code for this object.
no setterinherited
makerFeeRate double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
takerFeeRate double?
final
usdVolume double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

convertJson(Map<String, dynamic> jsonObject) Fee