Fill class

Constructors

Fill(int? tradeId, DateTime? createdAt, String? productId, String? orderId, String? userId, String? profileId, String? liquidity, double? price, double? size, double? fee, String? side, bool settled, double? usdVolume)
Fill.fromCBJson(Map<String, dynamic> json)
Fill.fromJson(Map<String, dynamic> json)

Properties

createdAt DateTime?
final
fee double?
final
hashCode int
The hash code for this object.
no setterinherited
liquidity String?
final
orderId String?
final
price double?
final
productId String?
final
profileId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settled bool
final
side String?
final
size double?
final
tradeId int?
final
usdVolume double?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited