Order class

Constructors

Order(String? id, String? clientOid, String? profileId, String? productId, String? side, double? price, double? size, double? funds, double? specifiedFunds, String? type, String? timeInForce, bool? postOnly, DateTime? createdAt, DateTime? expireTime, DateTime? doneAt, String? doneReason, String? rejectReason, double? fillFees, double? filledSize, double? executedValue, String? status, bool? settled, String? stop, double? stopPrice)
Order.fromCBJson(Map<String, dynamic> json)
Order.fromJson(Map<String, dynamic> json)

Properties

clientOid String?
final
createdAt DateTime?
final
doneAt DateTime?
final
doneReason String?
final
executedValue double?
final
expireTime DateTime?
final
filledSize double?
final
fillFees double?
final
funds double?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
postOnly bool?
final
price double?
final
productId String?
final
profileId String?
final
rejectReason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settled bool?
final
side String?
final
size double?
final
specifiedFunds double?
final
status String?
final
stop String?
final
stopPrice double?
final
timeInForce String?
final
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited