Ticker class

Constructors

Ticker(double? ask, double? bid, double? volume, int? tradeId, double? price, double? size, DateTime? time)

Properties

ask double?
final
bid double?
final
hashCode int
The hash code for this object.
no setterinherited
price double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
final
time DateTime?
final
tradeId int?
final
volume double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

convertJson(Map<String, dynamic> jsonObject) Ticker