Account class
Constructors
Properties
- available → double?
-
final
- balance → double?
-
final
- currency → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hold → double?
-
final
- id → String?
-
final
- profileId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tradingEnabled → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertJson(
Map< String, dynamic> jsonObject) → Account