Product class
Constructors
- Product(String? id, String? baseCurrency, String? quoteCurrency, double? quoteIncrement, double? baseIncrement, String? displayName, double? minMarketFunds, bool marginEnabled, bool postOnly, bool limitOnly, bool cancelOnly, String? status, String? statusMessage, bool tradingDisabled, bool fxStablecoin, double? maxSlippagePercentage, bool auctionMode)
Properties
- auctionMode → bool
-
final
- baseCurrency → String?
-
final
- baseIncrement → double?
-
final
- cancelOnly → bool
-
final
- displayName → String?
-
final
- fxStablecoin → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- limitOnly → bool
-
final
- marginEnabled → bool
-
final
- maxSlippagePercentage → double?
-
final
- minMarketFunds → double?
-
final
- postOnly → bool
-
final
- quoteCurrency → String?
-
final
- quoteIncrement → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
final
- statusMessage → String?
-
final
- tradingDisabled → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertJson(
Map< String, dynamic> jsonObject) → Product